==> mingw-w64-i686-opencolorio-1.1.1-9-any.pkg.tar.zst: mingw32/lib/cmake/OpenColorIO/OpenColorIO-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "OpenColorIO" for configuration "Release"
set_property(TARGET OpenColorIO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(OpenColorIO PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libOpenColorIO.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libtinyxml.dll.a;${_IMPORT_PREFIX}/lib/libyaml-cpp.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libOpenColorIO.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS OpenColorIO )
list(APPEND _IMPORT_CHECK_FILES_FOR_OpenColorIO "${_IMPORT_PREFIX}/lib/libOpenColorIO.dll.a" "${_IMPORT_PREFIX}/bin/libOpenColorIO.dll" )

# Import target "OpenColorIO_STATIC" for configuration "Release"
set_property(TARGET OpenColorIO_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(OpenColorIO_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libOpenColorIO.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS OpenColorIO_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_OpenColorIO_STATIC "${_IMPORT_PREFIX}/lib/libOpenColorIO.a" )

# Import target "ocioconvert" for configuration "Release"
set_property(TARGET ocioconvert APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ocioconvert PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ocioconvert.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ocioconvert )
list(APPEND _IMPORT_CHECK_FILES_FOR_ocioconvert "${_IMPORT_PREFIX}/bin/ocioconvert.exe" )

# Import target "ociolutimage" for configuration "Release"
set_property(TARGET ociolutimage APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociolutimage PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociolutimage.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociolutimage )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociolutimage "${_IMPORT_PREFIX}/bin/ociolutimage.exe" )

# Import target "ociodisplay" for configuration "Release"
set_property(TARGET ociodisplay APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociodisplay PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociodisplay.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociodisplay )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociodisplay "${_IMPORT_PREFIX}/bin/ociodisplay.exe" )

# Import target "ociocheck" for configuration "Release"
set_property(TARGET ociocheck APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociocheck PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociocheck.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociocheck )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociocheck "${_IMPORT_PREFIX}/bin/ociocheck.exe" )

# Import target "ociobakelut" for configuration "Release"
set_property(TARGET ociobakelut APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociobakelut PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociobakelut.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociobakelut )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociobakelut "${_IMPORT_PREFIX}/bin/ociobakelut.exe" )

# Import target "PyOpenColorIO" for configuration "Release"
set_property(TARGET PyOpenColorIO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(PyOpenColorIO PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.8/site-packages/PyOpenColorIO-cpython-38.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS PyOpenColorIO )
list(APPEND _IMPORT_CHECK_FILES_FOR_PyOpenColorIO "${_IMPORT_PREFIX}/lib/python3.8/site-packages/PyOpenColorIO-cpython-38.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-i686-opencolorio-1.1.1-13-any.pkg.tar.zst: mingw32/lib/cmake/OpenColorIO/OpenColorIO-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "OpenColorIO" for configuration "Release"
set_property(TARGET OpenColorIO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(OpenColorIO PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libOpenColorIO.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libtinyxml.dll.a;${_IMPORT_PREFIX}/lib/libyaml-cpp.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libOpenColorIO.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS OpenColorIO )
list(APPEND _IMPORT_CHECK_FILES_FOR_OpenColorIO "${_IMPORT_PREFIX}/lib/libOpenColorIO.dll.a" "${_IMPORT_PREFIX}/bin/libOpenColorIO.dll" )

# Import target "OpenColorIO_STATIC" for configuration "Release"
set_property(TARGET OpenColorIO_STATIC APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(OpenColorIO_STATIC PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libOpenColorIO.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS OpenColorIO_STATIC )
list(APPEND _IMPORT_CHECK_FILES_FOR_OpenColorIO_STATIC "${_IMPORT_PREFIX}/lib/libOpenColorIO.a" )

# Import target "ocioconvert" for configuration "Release"
set_property(TARGET ocioconvert APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ocioconvert PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ocioconvert.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ocioconvert )
list(APPEND _IMPORT_CHECK_FILES_FOR_ocioconvert "${_IMPORT_PREFIX}/bin/ocioconvert.exe" )

# Import target "ociolutimage" for configuration "Release"
set_property(TARGET ociolutimage APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociolutimage PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociolutimage.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociolutimage )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociolutimage "${_IMPORT_PREFIX}/bin/ociolutimage.exe" )

# Import target "ociodisplay" for configuration "Release"
set_property(TARGET ociodisplay APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociodisplay PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociodisplay.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociodisplay )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociodisplay "${_IMPORT_PREFIX}/bin/ociodisplay.exe" )

# Import target "ociocheck" for configuration "Release"
set_property(TARGET ociocheck APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociocheck PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociocheck.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociocheck )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociocheck "${_IMPORT_PREFIX}/bin/ociocheck.exe" )

# Import target "ociobakelut" for configuration "Release"
set_property(TARGET ociobakelut APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ociobakelut PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/ociobakelut.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS ociobakelut )
list(APPEND _IMPORT_CHECK_FILES_FOR_ociobakelut "${_IMPORT_PREFIX}/bin/ociobakelut.exe" )

# Import target "PyOpenColorIO" for configuration "Release"
set_property(TARGET PyOpenColorIO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(PyOpenColorIO PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.9/site-packages/PyOpenColorIO.cp39-mingw_i686.pyd"
  )

list(APPEND _IMPORT_CHECK_TARGETS PyOpenColorIO )
list(APPEND _IMPORT_CHECK_FILES_FOR_PyOpenColorIO "${_IMPORT_PREFIX}/lib/python3.9/site-packages/PyOpenColorIO.cp39-mingw_i686.pyd" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
